@@ -141,10 +141,9 @@ where
     ///     - `*(<Orphan>).get_mut() = ...`
     /// - **NEVER** do this:
     ///     - `*(&mut <Orphan>) = Orphan::new(...)`
-    ///     - OR you will loss the 'versioned' ability of this object
-    pub fn get_mut(&self) -> OrphanMut<'_, T> {
+    pub fn get_mut(&self) -> ValueMut<'_, T> {
         let value = self.get_value();
-        OrphanMut { hdr: self, value }
+        ValueMut { hdr: self, value }
     }
 }
 
@@ -277,7 +276,7 @@ impl_ops!(@Neg, neg, -);
 ////////////////////////////////////////////////////////////////////
 
 /// A type returned by `get_mut()`.
-pub struct OrphanMut<'a, T>
+pub struct ValueMut<'a, T>
 where
     T: ValueEnDe,
 {
@@ -285,7 +284,7 @@ where
     value: T,
 }
 
-impl<'a, T> Drop for OrphanMut<'a, T>
+impl<'a, T> Drop for ValueMut<'a, T>
 where
     T: ValueEnDe,
 {
@@ -294,7 +293,7 @@ where
     }
 }
 
-impl<'a, T> Deref for OrphanMut<'a, T>
+impl<'a, T> Deref for ValueMut<'a, T>
 where
     T: ValueEnDe,
 {
@@ -304,7 +303,7 @@ where
     }
 }
 
-impl<'a, T> DerefMut for OrphanMut<'a, T>
+impl<'a, T> DerefMut for ValueMut<'a, T>
 where
     T: ValueEnDe,
 {
@@ -315,16 +314,3 @@ where
 
 ////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////
-
-impl<T> Iterator for Orphan<T>
-where
-    T: ValueEnDe + Eq,
-{
-    type Item = T;
-    fn next(&mut self) -> Option<Self::Item> {
-        Some(self.get_value())
-    }
-}
-
-////////////////////////////////////////////////////////////////////
-////////////////////////////////////////////////////////////////////
