@@ -11,7 +11,7 @@ use ruc::*;
 use serde::{Deserialize, Serialize};
 use std::{
     marker::PhantomData,
-    ops::{Bound, RangeBounds},
+    ops::{Bound, Deref, DerefMut, RangeBounds},
 };
 
 /// Documents => [MapxRawVs](crate::versioned::mapx_raw::MapxRawVs)
@@ -54,6 +54,16 @@ where
         self.inner.get(&key.encode())
     }
 
+    #[inline(always)]
+    pub fn get_mut<'a>(&'a self, key: &'a K) -> Option<ValueMut<'a, K, V>> {
+        self.get(key).map(move |v| ValueMut::new(self, key, v))
+    }
+
+    #[inline(always)]
+    pub fn entry_ref<'a>(&'a self, key: &'a K) -> Entry<'a, K, V> {
+        Entry { key, hdr: self }
+    }
+
     #[inline(always)]
     pub fn get_le(&self, key: &K) -> Option<(K, V)> {
         self.inner
@@ -427,3 +437,77 @@ where
     V: ValueEnDe,
 {
 }
+
+#[derive(PartialEq, Eq, Debug)]
+pub struct ValueMut<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    hdr: &'a MapxVs<K, V>,
+    key: &'a K,
+    value: V,
+}
+
+impl<'a, K, V> ValueMut<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    fn new(hdr: &'a MapxVs<K, V>, key: &'a K, value: V) -> Self {
+        ValueMut { hdr, key, value }
+    }
+}
+
+impl<'a, K, V> Drop for ValueMut<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    fn drop(&mut self) {
+        pnk!(self.hdr.insert_ref(self.key, &self.value));
+    }
+}
+
+impl<'a, K, V> Deref for ValueMut<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    type Target = V;
+    fn deref(&self) -> &Self::Target {
+        &self.value
+    }
+}
+
+impl<'a, K, V> DerefMut for ValueMut<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.value
+    }
+}
+
+pub struct Entry<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    key: &'a K,
+    hdr: &'a MapxVs<K, V>,
+}
+
+impl<'a, K, V> Entry<'a, K, V>
+where
+    K: KeyEnDe,
+    V: ValueEnDe,
+{
+    pub fn or_insert(self, default: &V) -> ValueMut<'a, K, V> {
+        if !self.hdr.contains_key(self.key) {
+            pnk!(self.hdr.insert_ref(self.key, default));
+        }
+        pnk!(self.hdr.get_mut(self.key))
+    }
+}
